@@ -6,6 +6,10 @@ ggplot2::ggplot
 #' @export
 ggplot2::ggtitle
 
+#' @importFrom ggplot2 labs
+#' @export
+ggplot2::labs
+
 #' @importFrom gridExtra grid.arrange
 #' @export
 gridExtra::grid.arrange
