@@ -144,7 +144,7 @@ to_main_component.igraph <- function(object) {
 
 #' @rdname to
 #' @importFrom igraph delete_edges edge_attr_names delete_edge_attr
-#' @importFrom igraph E get.edge.attribute
+#' @importFrom igraph E get.edge.attribute edge_attr_names
 #' @examples
 #' to_uniplex(ison_m182, "friend_tie")
 #' @export
@@ -165,6 +165,7 @@ to_uniplex.igraph <- function(object, edge){
       out <- igraph::delete_edge_attr(out, e) 
     }
   }
+  if(is.numeric(igraph::get.edge.attribute(object, edge))) names(igraph::edge_attr(out)) <- "weight"
   out
 }
 
@@ -220,9 +221,8 @@ to_named <- function(object) UseMethod("to_named")
 
 #' @export
 to_named.tbl_graph <- function(object) {
-  as_tidygraph(object) %>%
-    mutate(name = sample(baby_names,
-                         igraph::vcount(object)))
+  object %>% mutate(name = sample(baby_names,
+                                  igraph::vcount(object)))
 }
 
 #' @export
@@ -231,3 +231,22 @@ to_named.igraph <- function(object) {
                                     igraph::vcount(object))
   object
 }
+
+#' @rdname to
+#' @examples
+#' to_multilevel(mpn_elite_usa_advice)
+#' @export
+to_multilevel <- function(object) UseMethod("to_multilevel")
+
+#' @export
+to_multilevel.tbl_graph <- function(object) {
+  as_tidygraph(to_multilevel(as_igraph(object)))
+}
+
+#' @export
+to_multilevel.igraph <- function(object) {
+  igraph::V(object)$lvl <- ifelse(igraph::V(object)$type, 2, 1)
+  object <- igraph::delete_vertex_attr(object, "type")
+  object
+}
+
